@@ -58,13 +58,12 @@ from pg8000.legacy import (
     VARCHAR_ARRAY,
     Warning,
     XID,
+    __version__,
+    pginterval_in,
+    pginterval_out,
+    timedelta_in,
 )
 
-from ._version import get_versions
-
-__version__ = get_versions()["version"]
-del get_versions
-
 # Copyright (c) 2007-2009, Mathieu Fenniak
 # Copyright (c) The Contributors
 # All rights reserved.
@@ -93,8 +92,6 @@ del get_versions
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-__author__ = "Mathieu Fenniak"
-
 
 def connect(
     user,
@@ -148,64 +145,68 @@ paramstyle = "format"
 
 
 __all__ = [
-    Warning,
-    DataError,
-    DatabaseError,
-    connect,
-    InterfaceError,
-    ProgrammingError,
-    Error,
-    OperationalError,
-    IntegrityError,
-    InternalError,
-    NotSupportedError,
-    Connection,
-    Cursor,
-    Binary,
-    Date,
-    DateFromTicks,
-    Time,
-    TimeFromTicks,
-    Timestamp,
-    TimestampFromTicks,
-    BINARY,
-    PGInterval,
-    STRING,
-    NUMBER,
-    DATETIME,
-    TIME,
-    BOOLEAN,
-    INTEGER,
-    BIGINTEGER,
-    INTERVAL,
-    JSON,
-    JSONB,
-    UNKNOWN,
-    NULLTYPE,
-    ROWID,
-    BOOLEAN_ARRAY,
-    BYTES,
-    CHAR,
-    CHAR_ARRAY,
-    DATE,
-    DECIMAL,
-    DECIMAL_ARRAY,
-    FLOAT,
-    FLOAT_ARRAY,
-    INET,
-    INT2VECTOR,
-    INTEGER_ARRAY,
-    MACADDR,
-    NAME,
-    NAME_ARRAY,
-    OID,
-    TEXT,
-    TEXT_ARRAY,
-    TIMEDELTA,
-    TIMESTAMP,
-    TIMESTAMPTZ,
-    UUID_TYPE,
-    VARCHAR,
-    VARCHAR_ARRAY,
-    XID,
+    "BIGINTEGER",
+    "BINARY",
+    "BOOLEAN",
+    "BOOLEAN_ARRAY",
+    "BYTES",
+    "Binary",
+    "CHAR",
+    "CHAR_ARRAY",
+    "Connection",
+    "Cursor",
+    "DATE",
+    "DATETIME",
+    "DECIMAL",
+    "DECIMAL_ARRAY",
+    "DataError",
+    "DatabaseError",
+    "Date",
+    "DateFromTicks",
+    "Error",
+    "FLOAT",
+    "FLOAT_ARRAY",
+    "INET",
+    "INT2VECTOR",
+    "INTEGER",
+    "INTEGER_ARRAY",
+    "INTERVAL",
+    "IntegrityError",
+    "InterfaceError",
+    "InternalError",
+    "JSON",
+    "JSONB",
+    "MACADDR",
+    "NAME",
+    "NAME_ARRAY",
+    "NULLTYPE",
+    "NUMBER",
+    "NotSupportedError",
+    "OID",
+    "OperationalError",
+    "PGInterval",
+    "ProgrammingError",
+    "ROWID",
+    "STRING",
+    "TEXT",
+    "TEXT_ARRAY",
+    "TIME",
+    "TIMEDELTA",
+    "TIMESTAMP",
+    "TIMESTAMPTZ",
+    "Time",
+    "TimeFromTicks",
+    "Timestamp",
+    "TimestampFromTicks",
+    "UNKNOWN",
+    "UUID_TYPE",
+    "VARCHAR",
+    "VARCHAR_ARRAY",
+    "Warning",
+    "XID",
+    "__version__",
+    "connect",
+    "pginterval_in",
+    "pginterval_out",
+    "timedelta_in",
 ]
